From 3fcf847e0cadfb9ede930f538c2f277483442175 Mon Sep 17 00:00:00 2001
From: xue <>
Date: Sat, 21 Jan 2006 17:29:40 +0000
Subject: BE AWARE: Significant change! Changed event definition from XXX to
OnXXX.
---
framework/Web/UI/WebControls/TCustomValidator.php | 8 ++++----
1 file changed, 4 insertions(+), 4 deletions(-)
(limited to 'framework/Web/UI/WebControls/TCustomValidator.php')
diff --git a/framework/Web/UI/WebControls/TCustomValidator.php b/framework/Web/UI/WebControls/TCustomValidator.php
index 546f015b..e92ae828 100644
--- a/framework/Web/UI/WebControls/TCustomValidator.php
+++ b/framework/Web/UI/WebControls/TCustomValidator.php
@@ -22,7 +22,7 @@ Prado::using('System.Web.UI.WebControls.TBaseValidator');
* server-side or client-side or both) on an input component.
*
* To create a server-side validation function, provide a handler for
- * the {@link onServerValidate ServerValidate} event that performs the validation.
+ * the {@link onServerValidate OnServerValidate} event that performs the validation.
* The data string of the input control to validate can be accessed
* by {@link TServerValidateEventParameter::getValue Value} of the event parameter.
* The result of the validation should be stored in the
@@ -84,17 +84,17 @@ class TCustomValidator extends TBaseValidator
/**
* This method is invoked when the server side validation happens.
* It will raise the ServerValidate event.
* The method also allows derived classes to handle the event without attaching a delegate.
* Note The derived classes should call parent implementation
* to ensure the ServerValidate event is raised.
* @param string the value to be validated
* @return boolean whether the value is valid
*/
public function onServerValidate($value)
{
$param=new TServerValidateEventParameter($value,true);
- $this->raiseEvent('ServerValidate',$this,$param);
+ $this->raiseEvent('OnServerValidate',$this,$param);
return $param->getIsValid();
}
@@ -84,17 +84,17 @@ class TCustomValidator extends TBaseValidator
/**
* This method is invoked when the server side validation happens.
- * It will raise the ServerValidate event.
+ * It will raise the OnServerValidate event.
* The method also allows derived classes to handle the event without attaching a delegate.
* Note The derived classes should call parent implementation
@@ -84,17 +84,17 @@ class TCustomValidator extends TBaseValidator
* The method also allows derived classes to handle the event without attaching a delegate.
* Note The derived classes should call parent implementation
- * to ensure the ServerValidate event is raised.
+ * to ensure the OnServerValidate event is raised.
* @param string the value to be validated
* @return boolean whether the value is valid
--
cgit v1.2.3